==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/AppearanceImageType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p135820_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p874817_="https://jakarta.ee/xml/ns/jaxb" xmlns:p942898_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to define an image resource for an annotation's appearance generation.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for AppearanceImageType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="AppearanceImageType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}AppearanceType">
 *       <all>
 *         <element name="data" type="{http://schema.webpdf.de/1.0/operation}AppearanceFileDataType"/>
 *       </all>
 *       <attribute name="preserveAspectRatio" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AppearanceImageType", propOrder = {
    "data"
})
public class AppearanceImageType
    extends AppearanceType
{

    @XmlElement(required = true)
    protected AppearanceFileDataType data;
    @XmlAttribute(name = "preserveAspectRatio")
    protected Boolean preserveAspectRatio;

    /**
     * Gets the value of the data property.
     * 
     * @return
     *     possible object is
     *     {@link AppearanceFileDataType }
     *     
     */
    public AppearanceFileDataType getData() {
        return data;
    }

    /**
     * Sets the value of the data property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearanceFileDataType }
     *     
     */
    public void setData(AppearanceFileDataType value) {
        this.data = value;
    }

    public boolean isSetData() {
        return (this.data!= null);
    }

    /**
     * Gets the value of the preserveAspectRatio property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isPreserveAspectRatio() {
        if (preserveAspectRatio == null) {
            return false;
        } else {
            return preserveAspectRatio;
        }
    }

    /**
     * Sets the value of the preserveAspectRatio property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setPreserveAspectRatio(boolean value) {
        this.preserveAspectRatio = value;
    }

    public boolean isSetPreserveAspectRatio() {
        return (this.preserveAspectRatio!= null);
    }

    public void unsetPreserveAspectRatio() {
        this.preserveAspectRatio = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/AppearanceImageType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p105796_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p913707_="https://jakarta.ee/xml/ns/jaxb" xmlns:p931759_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to define an image resource for an annotation's appearance generation.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for AppearanceImageType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="AppearanceImageType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}AppearanceType">
 *       <all>
 *         <element name="data" type="{http://schema.webpdf.de/1.0/operation}AppearanceFileDataType"/>
 *       </all>
 *       <attribute name="preserveAspectRatio" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AppearanceImageType", propOrder = {
    "data"
})
public class AppearanceImageType
    extends AppearanceType
{

    @XmlElement(required = true)
    protected AppearanceFileDataType data;
    @XmlAttribute(name = "preserveAspectRatio")
    protected Boolean preserveAspectRatio;

    /**
     * Gets the value of the data property.
     * 
     * @return
     *     possible object is
     *     {@link AppearanceFileDataType }
     *     
     */
    public AppearanceFileDataType getData() {
        return data;
    }

    /**
     * Sets the value of the data property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearanceFileDataType }
     *     
     */
    public void setData(AppearanceFileDataType value) {
        this.data = value;
    }

    public boolean isSetData() {
        return (this.data!= null);
    }

    /**
     * Gets the value of the preserveAspectRatio property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isPreserveAspectRatio() {
        if (preserveAspectRatio == null) {
            return false;
        } else {
            return preserveAspectRatio;
        }
    }

    /**
     * Sets the value of the preserveAspectRatio property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setPreserveAspectRatio(boolean value) {
        this.preserveAspectRatio = value;
    }

    public boolean isSetPreserveAspectRatio() {
        return (this.preserveAspectRatio!= null);
    }

    public void unsetPreserveAspectRatio() {
        this.preserveAspectRatio = null;
    }

}
